Module assembler

Module assembler 

Structs

Assembler
LogicalImm

Constants

BLE

Traits

LoadConstantEmitter

Functions

count_zero_half_words_64
encode_fp64_to_imm8
encode_logical_imm
Encodes the given imm value of the given width to a logical immediate value represented as N, S, and R fields and writes these fields to out.
is_fp16_imm8
is_fp32_imm8
is_fp64_imm8