Module core

Module core 

Modules

arch_traits
buffer
emitter
formatter
Formatter core functionality
globals
jit_allocator
operand
Default operand types available across all backends. All Operands derive from Operand and all of them must be of the same size and downcast-able/upcast-able from/to Operand itself.
patch
sink
support
target
types