Structs
- AsmFixup
- A fixup to perform on the buffer once code is emitted. Fixups always refer to labels and patch the code based on label offsets. Hence, they are like relocations, but internal to one buffer.
- AsmReloc
- A relocation resulting from emitting assembly.
- Code
Buffer - A buffer of output to be produced, fixed up, and then emitted to a CodeSink in bulk.
- Code
Buffer Finalized - A
CodeBufferonce emission is completed: holds generated code and records, without fixups. This allows the type to be independent of the backend. - Constant
- A use of a constant by one or mroe assembly instructions.
- Loaded
Relocated Code - Executable memory loaded from a finalized code buffer with relocations applied.
Enums
- Constant
Data - External
Name - Label
Use - Reloc
- Relocation kinds for every ISA
- Reloc
Distance - Reloc
Target
Functions
- got_
slot_ index - is_
imm12 - perform_
relocations ⚠ - A generic implementation of relocation resolving.
- reloc_
uses_ got
Type Aliases
- Addend
- Addend to add to the symbol value.
- Code
Offset - Offset in bytes from the beginning of the function.