Default operand types available across all backends. All Operands derive from Operand and all of them
must be of the same size and downcast-able/upcast-able from/to Operand itself.
Structs
Enums
- ImmType
- Operand
Type - Operand type used by Operand
- RegGroup
- RegType
- Register type.
Constants
- DATA_
IMM_ VALUE_ HI - DATA_
IMM_ VALUE_ LO - DATA_
MEM_ INDEX_ ID - DATA_
MEM_ OFFSET_ LO - REG_
BASE_ SIGNATURE_ MASK - REG_
SIGNATURE - REG_
TYPE_ NONE - VIRT_
ID_ COUNT - VIRT_
ID_ MAX - VIRT_
ID_ MIN
Traits
- Operand
Cast - A helper trait to help cast Operand to Architecture dependent operands and vice-versa.
- RegTraits