Operand

Struct Operand 

pub struct Operand {
    pub signature: OperandSignature,
    pub base_id: u32,
    pub data: [u32; 2],
}
Base struct representing an operand in asmkit.

This struct is used internally and all types that are valid operands downcast to this type eventually and it’s also possible to “upcast” it to a operand type e.g Gp.

Fields

signature: OperandSignaturebase_id: u32data: [u32; 2]

Implementations

Source

impl Operand

pub const fn new() -> Self

pub const fn make_reg(sig: OperandSignature, id: u32) -> Self

pub fn reset(&mut self)

pub fn has_signature(&self, other: OperandSignature) -> bool

pub const fn signature(&self) -> OperandSignature

pub fn set_signature(&mut self, sig: OperandSignature)

pub fn set_id(&mut self, id: u32)

pub fn op_type(&self) -> OperandType

pub const fn is_none(&self) -> bool

pub fn is_reg(&self) -> bool

pub fn is_reg_list(&self) -> bool

pub fn is_mem(&self) -> bool

pub fn is_imm(&self) -> bool

pub fn is_label(&self) -> bool

pub fn is_sym(&self) -> bool

pub fn is_phys_reg(&self) -> bool

pub fn is_virt_reg(&self) -> bool

pub const fn id(&self) -> u32

pub fn is_reg_type_of(&self, typ: RegType) -> bool

pub fn is_reg_group_of(&self, group: RegGroup) -> bool

pub fn is_gp(&self) -> bool

pub fn is_gp32(&self) -> bool

pub fn is_gp64(&self) -> bool

pub fn is_vec(&self) -> bool

pub fn is_vec8(&self) -> bool

pub fn is_vec16(&self) -> bool

pub fn is_vec32(&self) -> bool

pub fn is_vec64(&self) -> bool

pub fn is_vec128(&self) -> bool

pub fn is_vec256(&self) -> bool

pub fn is_vec512(&self) -> bool

pub fn is_mask(&self) -> bool

pub fn is_reg_list_of(&self, typ: RegType) -> bool

pub fn is_reg_or_mem(&self) -> bool

pub fn is_reg_or_reg_list_or_mem(&self) -> bool

pub fn x86_rm_size(&self) -> u32

Source

impl Operand

pub fn as_<T>(&self) -> T
where T: OperandCast,