Module masm

Module masm 

MacroAssembler infrastructure

This module provides “portable” assembler across all supported architectures.

It is a best effort to provide a common API across all architectures, but some features may be architecture specific.

Structs

JumpList

Enums

DoubleCondition
ExtensionSize
RelationalCondition
ResultCondition

Functions

imm_fits