pub trait CLhEmitter<T0, T1, T2> {
// Required method
fn c_lh(&mut self, rd: T0, rs1: T1, imm: T2);
}Expand description
Load signed halfword, 16-bit encoding
Loads a 16-bit value from memory into register rd.
It computes an effective address by adding the zero-extended offset, to the base address in register rs1.
It expands to lh rd, offset(rs1).
Forms
Assembly: c.lh xd, imm(xs1)
Rust: c_lh(rd, rs1, imm)
Arguments
rd— Destination register.rs1— Source register.imm— Immediate encoding value.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".