pub trait CShEmitter<T0, T1, T2> {
// Required method
fn c_sh(&mut self, rs1: T0, rs2: T1, imm: T2);
}Expand description
Store unsigned halfword, 16-bit encoding
Stores a 16-bit value from register rs2 into memory.
It computes an effective address by adding the zero-extended offset, to the base address in register rs1.
It expands to sh rs2, offset(rs1).
Forms
Assembly: c.sh xs2, imm(xs1)
Rust: c_sh(rs1, rs2, imm)
Arguments
rs1— Source register.rs2— Source register.imm— Immediate encoding value.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".