CSraiEmitter

Trait CSraiEmitter 

pub trait CSraiEmitter<T0, T1> {
    // Required method
    fn c_srai(&mut self, rd: T0, imm: T1);
}
Shift right arithmetical immediate

Arithmetic shift (the original sign bit is copied into the vacated upper bits) the value in rd right by shamt, and store the result in rd. The rd register index should be used as rd+8 (registers x8-x15). C.SRAI expands into srai rd, rd, shamt.

Forms

Assembly: c.srai xd, shamt Rust: c_srai(rd, imm)

Arguments

  • rd — Destination/source register.
  • imm — Immediate encoding value.

Required Methods

fn c_srai(&mut self, rd: T0, imm: T1)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<U1: Into<Imm>> CSraiEmitter<Gp, U1> for Assembler<'_>