pub trait CSrliEmitter<T0, T1> {
// Required method
fn c_srli(&mut self, rd: T0, imm: T1);
}Expand description
Shift right logical immediate
Shift the value in rd right by shamt, and store the result back in rd.
The rd register index should be used as rd+8 (registers x8-x15).
C.SRLI expands into srli rd, rd, shamt.
Forms
Assembly: c.srli xd, shamt
Rust: c_srli(rd, imm)
Arguments
rd— Destination/source register.imm— Immediate encoding value.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".