EbreakEmitter

Trait EbreakEmitter 

pub trait EbreakEmitter {
    // Required method
    fn ebreak(&mut self);
}
Breakpoint exception

The EBREAK instruction is used by debuggers to cause control to be transferred back to a debugging environment. Unless overridden by an external debug environment, EBREAK raises a breakpoint exception and performs no other operation.

[NOTE] As described in the C Standard Extension for Compressed Instructions, the c.ebreak instruction performs the same operation as the EBREAK instruction.

EBREAK causes the receiving privilege mode’s epc register to be set to the address of the EBREAK instruction itself, not the address of the following instruction. As EBREAK causes a synchronous exception, it is not considered to retire, and should not increment the minstret CSR.

Forms

Assembly: ebreak "" Rust: ebreak()

Arguments

Required Methods

fn ebreak(&mut self)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors