pub trait Rev8Emitter<T0, T1> {
// Required method
fn rev8(&mut self, rd: T0, rs1: T1);
}Expand description
Byte-reverse register (RV64 encoding)
This instruction reverses the order of the bytes in rs1.
[NOTE] The rev8 mnemonic corresponds to different instruction encodings in RV32 and RV64.
[NOTE]
The byte-reverse operation is only available for the full register width. To emulate word-sized
and halfword-sized byte-reversal, perform a rev8 rd,rs followed by a srai rd,rd,K, where K
is XLEN-32 and XLEN-16, respectively.
Forms
Assembly: rev8 xd, xs1
Rust: rev8(rd, rs1)
Arguments
rd— Destination register.rs1— Source register.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".