ZextHEmitter

Trait ZextHEmitter 

pub trait ZextHEmitter<T0, T1> {
    // Required method
    fn zext_h(&mut self, rd: T0, rs1: T1);
}
Zero-extend halfword

This instruction zero-extends the least-significant halfword of the source to XLEN by inserting 0’s into all of the bits more significant than 15.

[NOTE] The zext.h instruction is a pseudo-op for pack when Zbkb is implemented and XLEN == 32.

[NOTE] The zext.h instruction is a pseudo-op for packw when Zbkb is implemented and XLEN == 64.

Forms

Assembly: zext.h xd, xs1 Rust: zext_h(rd, rs1)

Arguments

  • rd — Destination register.
  • rs1 — Source register.

Required Methods

fn zext_h(&mut self, rd: T0, rs1: T1)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors