ZipEmitter

Trait ZipEmitter 

pub trait ZipEmitter<T0, T1> {
    // Required method
    fn zip(&mut self, rd: T0, rs1: T1);
}
Bit interleave

This instruction scatters all of the odd and even bits of a source word into the high and low halves of a destination word. It is the inverse of the unzip instruction. This instruction is available only on RV32.

Forms

Assembly: zip xd, xs1 Rust: zip(rd, rs1)

Arguments

  • rd — Destination register.
  • rs1 — Source register.

Required Methods

fn zip(&mut self, rd: T0, rs1: T1)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors