CodeBufferFinalized

Struct CodeBufferFinalized 

pub struct CodeBufferFinalized { /* private fields */ }
A CodeBuffer once emission is completed: holds generated code and records, without fixups. This allows the type to be independent of the backend.

Implementations

Source

impl CodeBufferFinalized

pub fn total_size(&self) -> usize

pub fn data(&self) -> &[u8]

pub fn symbol_name(&self, sym: Sym) -> Option<&ExternalName>

pub fn symbol_distance(&self, sym: Sym) -> Option<RelocDistance>

pub fn defined_symbol_offset(&self, name: &ExternalName) -> Option<CodeOffset>

Offset of a symbol exported with CodeBuffer::bind_symbol, if present.

After loading, the runtime address of the symbol is rx + offset.

pub fn defined_symbol_str(&self, name: &str) -> Option<CodeOffset>

pub fn relocs(&self) -> &[AsmReloc]

pub fn alignment(&self) -> u32

Source

impl CodeBufferFinalized