pub struct InstRwInfo {
pub inst_flags: InstRwFlags,
pub read_flags: CpuRwFlags,
pub write_flags: CpuRwFlags,
pub op_count: u8,
pub rm_feature: u8,
pub extra_reg: OpRwInfo,
pub operands: [OpRwInfo; 6],
}Expand description
Read/write information of an instruction.
Fields
inst_flags: InstRwFlagsInstruction flags.
read_flags: CpuRwFlagsCPU flags read.
write_flags: CpuRwFlagsCPU flags written.
op_count: u8Count of operands.
rm_feature: u8CPU feature required for replacing register operand with memory operand (architecture-specific feature id, 0 = none).
extra_reg: OpRwInfoRead/write info of the extra register (rep{} or {k} selector).
operands: [OpRwInfo; 6]Read/write info of instruction operands.
Implementations
Sourceimpl InstRwInfo
impl InstRwInfo
Sourcepub const fn is_mov_op(&self) -> bool
pub const fn is_mov_op(&self) -> bool
Tests whether this instruction is a move operation (see InstRwFlags::MOV_OP).
Sourcepub fn operands(&self) -> &[OpRwInfo]
pub fn operands(&self) -> &[OpRwInfo]
Returns read/write info of operands as a slice, truncated to op_count.
Sourcepub fn operands_mut(&mut self) -> &mut [OpRwInfo]
pub fn operands_mut(&mut self) -> &mut [OpRwInfo]
Returns read/write info of operands as a mutable slice, truncated to op_count.