pub struct PatchableSite { /* private fields */ }Expand description
Self-describing handle for a patchable displacement (jump/call).
Implementations
Sourceimpl PatchableSite
impl PatchableSite
Sourcepub const unsafe fn new(offset: CodeOffset, kind: LabelUse, addend: i64) -> Self
pub const unsafe fn new(offset: CodeOffset, kind: LabelUse, addend: i64) -> Self
Construct a site handle manually.
Safety
offset in any image you later patch must be a valid displacement field of kind
with the same layout as when the site was emitted or recorded.
pub const fn offset(self) -> CodeOffset
pub const fn kind(self) -> LabelUse
pub const fn addend(self) -> i64
Sourcepub unsafe fn retarget(
self,
bytes: &mut [u8],
target_offset: CodeOffset,
) -> Result<(), AsmError>
pub unsafe fn retarget( self, bytes: &mut [u8], target_offset: CodeOffset, ) -> Result<(), AsmError>
Retarget this site in a mutable code image.
Safety
bytes must be the code image this site was recorded against (same layout). The caller
synchronizes concurrent execution of the patched region.