pub trait FcomppEmitter {
// Required method
fn fcompp(&mut self);
}Expand description
FCOMPP (FCOMPP).
Compares the contents of register ST(0) and source value and sets condition code flags C0, C2, and C3 in the FPU status word according to the results (see the table below). The source operand can be a data register or a memory location. If no source operand is given, the value in ST(0) is compared with the value in ST(1). The sign of zero is ignored, so that –0.0 is equal to +0.0.
For more details, see the Intel manual.
Supported operand variants:
+---+----------+
| # | Operands |
+---+----------+
| 1 | (none) |
+---+----------+