FinitEmitter

Trait FinitEmitter 

pub trait FinitEmitter {
    // Required method
    fn finit(&mut self);
}
FINIT (FINIT). Sets the FPU control, status, tag, instruction pointer, and data pointer registers to their default states. The FPU control word is set to 037FH (round to nearest, all exceptions masked, 64-bit precision). The status word is cleared (no exception flags set, TOP is set to 0). The data registers in the register stack are left unchanged, but they are all tagged as empty (11B). Both the instruction and data pointers are cleared.

For more details, see the Intel manual.

Supported operand variants:

+---+----------+
| # | Operands |
+---+----------+
| 1 | (none)   |
+---+----------+

Required Methods

fn finit(&mut self)

Implementors