InvdEmitter

Trait InvdEmitter 

pub trait InvdEmitter {
    // Required method
    fn invd(&mut self);
}
INVD (INVD). Invalidates (flushes) the processor’s internal caches and issues a special-function bus cycle that directs external caches to also flush themselves. Data held in internal caches is not written back to main memory.

For more details, see the Intel manual.

Supported operand variants:

+---+----------+
| # | Operands |
+---+----------+
| 1 | (none)   |
+---+----------+

Required Methods

fn invd(&mut self)

Implementors