FucomiEmitter

Trait FucomiEmitter 

pub trait FucomiEmitter<A> {
    // Required method
    fn fucomi(&mut self, op0: A);
}
FUCOMI (FUCOMI). Performs an unordered comparison of the contents of registers ST(0) and ST(i) and sets the status flags ZF, PF, and CF in the EFLAGS register according to the results (see the table below). The sign of zero is ignored for comparisons, so that –0.0 is equal to +0.0.

For more details, see the Intel manual.

Supported operand variants:

+---+----------+
| # | Operands |
+---+----------+
| 1 | St       |
+---+----------+

Required Methods

fn fucomi(&mut self, op0: A)

Implementors