SysenterEmitter

Trait SysenterEmitter 

pub trait SysenterEmitter {
    // Required method
    fn sysenter(&mut self);
}
SYSENTER (SYSENTER). Executes a fast call to a level 0 system procedure or routine. SYSENTER is a companion instruction to SYSEXIT. The instruction is optimized to provide the maximum performance for system calls from user code running at privilege level 3 to operating system or executive procedures running at privilege level 0.

For more details, see the Intel manual.

Supported operand variants:

+---+----------+
| # | Operands |
+---+----------+
| 1 | (none)   |
+---+----------+

Required Methods

fn sysenter(&mut self)

Implementors