JsEmitter

Trait JsEmitter 

pub trait JsEmitter<A> {
    // Required method
    fn js(&mut self, op0: A);
}
JS (JS). Checks the state of one or more of the status flags in the EFLAGS register (CF, OF, PF, SF, and ZF) and, if the flags are in the specified state (condition), performs a jump to the target instruction specified by the destination operand. A condition code (cc) is associated with each instruction to indicate the condition being tested for. If the condition is not satisfied, the jump is not performed and execution continues with the instruction following the Jcc instruction.

For more details, see the Intel manual.

Supported operand variants:

+---+----------+
| # | Operands |
+---+----------+
| 1 | Imm      |
| 2 | Label    |
| 3 | Sym      |
+---+----------+

Required Methods

fn js(&mut self, op0: A)

Implementors

Source

impl<'a> JsEmitter<Imm> for Assembler<'a>

Source

impl<'a> JsEmitter<Label> for Assembler<'a>

Source

impl<'a> JsEmitter<Sym> for Assembler<'a>