SetbeEmitter

Trait SetbeEmitter 

pub trait SetbeEmitter<A> {
    // Required method
    fn setbe(&mut self, op0: A);
}
SETBE (SETBE). Sets the destination operand to 0 or 1 depending on the settings of the status flags (CF, SF, OF, ZF, and PF) in the EFLAGS register. The destination operand points to a byte register or a byte in memory. The condition code suffix (cc) indicates the condition being tested for.

For more details, see the Intel manual.

Supported operand variants:

+---+----------+
| # | Operands |
+---+----------+
| 1 | GpbLo    |
| 2 | Mem      |
+---+----------+

Required Methods

fn setbe(&mut self, op0: A)

Implementors