StrEmitter

Trait StrEmitter 

pub trait StrEmitter<A> {
    // Required method
    fn str(&mut self, op0: A);
}
STR (STR). Stores the segment selector from the task register (TR) in the destination operand. The destination operand can be a general-purpose register or a memory location. The segment selector stored with this instruction points to the task state segment (TSS) for the currently running task.

For more details, see the Intel manual.

Supported operand variants:

+---+----------+
| # | Operands |
+---+----------+
| 1 | Gpd      |
| 2 | Mem      |
+---+----------+

Required Methods

fn str(&mut self, op0: A)

Implementors

Source

impl<'a> StrEmitter<Gpd> for Assembler<'a>

Source

impl<'a> StrEmitter<Mem> for Assembler<'a>