Prefetchwt1Emitter

Trait Prefetchwt1Emitter 

pub trait Prefetchwt1Emitter<A> {
    // Required method
    fn prefetchwt1(&mut self, op0: A);
}
PREFETCHWT1 (PREFETCHWT1). Fetches the line of data from memory that contains the byte specified with the source operand to a location in the cache hierarchy specified by an intent to write hint (so that data is brought into ‘Exclusive’ state via a request for ownership) and a locality hint

For more details, see the Intel manual.

Supported operand variants:

+---+----------+
| # | Operands |
+---+----------+
| 1 | Mem      |
+---+----------+

Required Methods

fn prefetchwt1(&mut self, op0: A)

Implementors