SerializeEmitter

Trait SerializeEmitter 

pub trait SerializeEmitter {
    // Required method
    fn serialize(&mut self);
}
SERIALIZE (SERIALIZE). Serializes instruction execution. Before the next instruction is fetched and executed, the SERIALIZE instruction ensures that all modifications to flags, registers, and memory by previous instructions are completed, draining all buffered writes to memory. This instruction is also a serializing instruction as defined in the section “Serializing Instructions” in Chapter 9 of the Intel® 64 and IA-32 Architectures Software Developer’s Manual, Volume 3A.

For more details, see the Intel manual.

Supported operand variants:

+---+----------+
| # | Operands |
+---+----------+
| 1 | (none)   |
+---+----------+

Required Methods

fn serialize(&mut self)

Implementors