Structs
Constants
Traits
Functions
- count_
zero_ half_ words_ 64 - encode_
fp64_ to_ imm8 - encode_
logical_ imm - Encodes the given
immvalue of the givenwidthto a logical immediate value represented as N, S, and R fields and writes these fields toout. - is_
fp16_ imm8 - is_
fp32_ imm8 - is_
fp64_ imm8