Module operand

Module operand 

Default operand types available across all backends. All Operands derive from Operand and all of them must be of the same size and downcast-able/upcast-able from/to Operand itself.

Structs

BaseMem
BaseReg
Imm
Label
Operand
Base struct representing an operand in asmkit.
OperandSignature
Sym

Enums

ImmType
OperandType
Operand type used by Operand
RegGroup
RegType
Register type.

Constants

DATA_IMM_VALUE_HI
DATA_IMM_VALUE_LO
DATA_MEM_INDEX_ID
DATA_MEM_OFFSET_LO
REG_BASE_SIGNATURE_MASK
REG_SIGNATURE
REG_TYPE_NONE
VIRT_ID_COUNT
VIRT_ID_MAX
VIRT_ID_MIN

Traits

OperandCast
A helper trait to help cast Operand to Architecture dependent operands and vice-versa.
RegTraits

Functions

imm
index_to_virt_id
is_virt_id
virt_id_to_index

Type Aliases

RegMask
Register mask is a convenience typedef that describes a mask where each bit describes a physical register id in the same RegGroup. At the moment 32 bits are enough as asmkit doesn’t support any architecture that would provide more than 32 registers for a register group.