pub trait CAddi16spEmitter<T0> {
// Required method
fn c_addi16sp(&mut self, imm: T0);
}Expand description
Add a sign-extended non-zero immediate
C.ADDI16SP adds the non-zero sign-extended 6-bit immediate to the value in the stack pointer (sp=x2), where the immediate is scaled to represent multiples of 16 in the range (-512,496).
C.ADDI16SP is used to adjust the stack pointer in procedure prologues and epilogues.
It expands into addi x2, x2, nzimm\[9:4\].
C.ADDI16SP is only valid when nzimm ≠ 0; the code point with nzimm=0 is reserved.
Forms
Assembly: c.addi16sp imm
Rust: c_addi16sp(imm)
Arguments
imm— Immediate encoding value.
Required Methods
fn c_addi16sp(&mut self, imm: T0)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".