pub trait CLbuEmitter<T0, T1, T2> {
// Required method
fn c_lbu(&mut self, rd: T0, rs1: T1, imm: T2);
}Expand description
Load unsigned byte, 16-bit encoding
Loads a 8-bit value from memory into register rd.
It computes an effective address by adding the zero-extended offset, to the base address in register rs1.
It expands to lbu rd, offset(rs1).
Forms
Assembly: c.lbu xd, imm(xs1)
Rust: c_lbu(rd, rs1, imm)
Arguments
rd— Destination register.rs1— Source register.imm— Immediate encoding value.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".