pub trait MaxEmitter<T0, T1, T2> {
// Required method
fn max(&mut self, rd: T0, rs1: T1, rs2: T2);
}Expand description
Maximum
This instruction returns the larger of two signed integers.
.Software Hint
[NOTE]
Calculating the absolute value of a signed integer can be performed using the
following sequence: neg rD,rS followed by `max rD,rS,rD. When using this
common sequence, it is suggested that they are scheduled with no intervening
instructions so that implementations that are so optimized can fuse them
together.
Forms
Assembly: max xd, xs1, xs2
Rust: max(rd, rs1, rs2)
Arguments
rd— Destination register.rs1— Source register.rs2— Source register.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".