InstRwInfo

Struct InstRwInfo 

pub struct InstRwInfo {
    pub inst_flags: InstRwFlags,
    pub read_flags: CpuRwFlags,
    pub write_flags: CpuRwFlags,
    pub op_count: u8,
    pub rm_feature: u8,
    pub extra_reg: OpRwInfo,
    pub operands: [OpRwInfo; 6],
}
Read/write information of an instruction.

Fields

inst_flags: InstRwFlags

Instruction flags.

read_flags: CpuRwFlags

CPU flags read.

write_flags: CpuRwFlags

CPU flags written.

op_count: u8

Count of operands.

rm_feature: u8

CPU feature required for replacing register operand with memory operand (architecture-specific feature id, 0 = none).

extra_reg: OpRwInfo

Read/write info of the extra register (rep{} or {k} selector).

operands: [OpRwInfo; 6]

Read/write info of instruction operands.

Implementations

Source

impl InstRwInfo

pub const fn new() -> Self

Returns this instruction info with all members reset to zero.

pub const fn is_mov_op(&self) -> bool

Tests whether this instruction is a move operation (see InstRwFlags::MOV_OP).

pub fn operands(&self) -> &[OpRwInfo]

Returns read/write info of operands as a slice, truncated to op_count.

pub fn operands_mut(&mut self) -> &mut [OpRwInfo]

Returns read/write info of operands as a mutable slice, truncated to op_count.

pub fn operand(&self, index: usize) -> Option<&OpRwInfo>

Returns read/write info of the operand at index, or None if out of range.