pub fn protect_jit_memory(access: ProtectJitAccess)Expand description
Protects access of memory mapped with MAP_JIT flag for the current thread.
Note
This feature is only available on Apple hardware (AArch64) at the moment and and uses a non-portable
pthread_jit_write_protect_np() call when available.
This function must be called before and after a memory mapped with MAP_JIT flag is modified.