X86 Assembler.
This module provides functionality for encoding x86 instructions.
Main entrypoint is the Assembler struct, which provides methods for encoding instructions.
NOTE
Dynamic code generation and text parsing are feature gated, enable x86-dyn and x86-asm respectively to use those features.
But be aware that they increase the size of the crate significantly, so they are not enabled by default.
Re-exports
pub use crate::X86Error;pub use crate::core::operand::imm;pub use assembler::*;pub use features::*;pub use operands::*;
Modules
- arch_
traits - assembler
- features
- opcodes
- operands
- X86 operands definition.