pub trait FucompEmitter<A> {
// Required method
fn fucomp(&mut self, op0: A);
}Expand description
FUCOMP (FUCOMP).
Performs an unordered comparison of the contents of register ST(0) and ST(i) and sets condition code flags C0, C2, and C3 in the FPU status word according to the results (see the table below). If no operand is specified, the contents of registers ST(0) and ST(1) are compared. The sign of zero is ignored, so that –0.0 is equal to +0.0.
For more details, see the Intel manual.
Supported operand variants:
+---+----------+
| # | Operands |
+---+----------+
| 1 | St |
+---+----------+