pub trait PrefetchwEmitter<A> {
// Required method
fn prefetchw(&mut self, op0: A);
}Expand description
PREFETCHW (PREFETCHW).
Fetches the cache line of data from memory that contains the byte specified with the source operand to a location in the 1st or 2nd level cache and invalidates other cached instances of the line.
For more details, see the Intel manual.
Supported operand variants:
+---+----------+
| # | Operands |
+---+----------+
| 1 | Mem |
+---+----------+