pub trait TpauseEmitter<A> {
// Required method
fn tpause(&mut self, op0: A);
}Expand description
TPAUSE (TPAUSE).
TPAUSE instructs the processor to enter an implementation-dependent optimized state. There are two such optimized states to choose from: light-weight power/performance optimized state, and improved power/performance optimized state. The selection between the two is governed by the explicit input register bit[0] source operand.
For more details, see the Intel manual.
Supported operand variants:
+---+----------+
| # | Operands |
+---+----------+
| 1 | Gpd |
+---+----------+