pub trait UmwaitEmitter<A> {
// Required method
fn umwait(&mut self, op0: A);
}Expand description
UMWAIT (UMWAIT).
UMWAIT instructs the processor to enter an implementation-dependent optimized state while monitoring a range of addresses. The optimized state may be either a light-weight power/performance optimized state or an improved power/performance optimized state. The selection between the two states is governed by the explicit input register bit[0] source operand.
For more details, see the Intel manual.
Supported operand variants:
+---+----------+
| # | Operands |
+---+----------+
| 1 | Gpd |
+---+----------+